@@ -9,7 +9,7 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-'''
+"""
 Module hosting a few shared constants.
-'''
-COUCHDB_ROOT = 'https://lhcb-couchdb.cern.ch/nightlies-nightly/'
+"""
+COUCHDB_ROOT = "https://lhcb-couchdb.cern.ch/nightlies-nightly/"
