@@ -33,38 +33,8 @@ latest_gaudi = "v27r1"
 
 def test_platform_sorting():
     from LbEnv.ProjectEnv.lookup import platform_sort_key
+    from random import shuffle
 
-    sorted_platforms = [
-        "i686-slc5-gcc43-dbg",
-        "i686-slc5-gcc43-opt",
-        "slc4_amd64_gcc34",
-        "slc4_ia32_gcc34",
-        "x86_64-centos7-gcc49-dbg",
-        "x86_64-centos7-gcc49-opt",
-        "x86_64-centos7-gcc62-dbg",
-        "x86_64-centos7-gcc62-do0",
-        "x86_64-centos7-gcc62-opt",
-        "x86_64-centos7-gcc7-dbg",
-        "x86_64-centos7-gcc7-do0",
-        "x86_64-centos7-gcc7-opt",
-        "x86_64-slc5-gcc43-dbg",
-        "x86_64-slc5-gcc43-opt",
-        "x86_64-slc5-gcc46-dbg",
-        "x86_64-slc5-gcc46-opt",
-        "x86_64-slc6-gcc46-dbg",
-        "x86_64-slc6-gcc46-opt",
-        "x86_64-slc6-gcc48-dbg",
-        "x86_64-slc6-gcc48-do0",
-        "x86_64-slc6-gcc48-opt",
-        "x86_64-slc6-gcc49-dbg",
-        "x86_64-slc6-gcc49-do0",
-        "x86_64-slc6-gcc49-opt",
-        "x86_64-slc6-gcc62-dbg",
-        "x86_64-slc6-gcc62-do0",
-        "x86_64-slc6-gcc62-opt",
-        "x86_64+avx2+fma-centos7-gcc62-dbg",
-        "x86_64+avx2+fma-centos7-gcc62-opt",
-    ]
     expected_order = [
         "x86_64-slc6-gcc48-do0",
         "x86_64-slc6-gcc49-do0",
@@ -84,6 +54,7 @@ def test_platform_sorting():
         "x86_64+avx2+fma-centos7-gcc62-dbg",
         "slc4_ia32_gcc34",
         "i686-slc5-gcc43-opt",
+        "x86_64-centos7-clang8-opt",
         "slc4_amd64_gcc34",
         "x86_64-slc5-gcc43-opt",
         "x86_64-slc5-gcc46-opt",
@@ -94,10 +65,18 @@ def test_platform_sorting():
         "x86_64-slc6-gcc62-opt",
         "x86_64-centos7-gcc62-opt",
         "x86_64-centos7-gcc7-opt",
+        "x86_64-centos7-gcc8-opt",
+        "x86_64-centos7-gcc10-opt",
         "x86_64+avx2+fma-centos7-gcc62-opt",
     ]
-    sorted_platforms.sort(key=platform_sort_key)
-    assert sorted_platforms == expected_order
+
+    for _ in range(100):
+        shuffled = list(expected_order)
+        shuffle(shuffled)
+        sorted_platforms = sorted(shuffled, key=platform_sort_key)
+        assert sorted_platforms == expected_order, "bad sorting: {} -> {}".format(
+            shuffled, sorted_platforms
+        )
 
 
 def prepare_tree(base, tree):
